Compilation on a Unix-like system — CALCEPH - Octave/Matlab language 3.4.1 documentation

All declarations needed to use CALCEPH Library are collected in the include file `calceph.h`. It is designed to work with both C and C++ compilers.

You should include that file in any program using the CALCEPH library:

    #include <calceph.h>

# Compilation on a Unix-like system

All programs using CALCEPH must link against the `libcalceph` library. On Unix-like system this can be done with -lcalceph, for example

>     gcc myprogram.c -o myprogram -lcalceph

If CALCEPH Library has been installed to a non-standard location then it may be necessary to use -I and -L compiler options to point to the right directories, and some sort of run-time path for a shared library.

# Compilation on a Windows system

- Using the Windows SDK

> All programs using CALCEPH must link against the `libcalceph.lib`. On Windows system this can be done with libcalceph.lib, for example

> >     cl.exe /out:myprogram myprogram.c libcalceph.lib

> If CALCEPH Library has been installed to a non-standard location then it may be necessary to use /I and /LIBPATH: compiler options to point to the right directories.

- Using the MinGW

> All programs using CALCEPH must link against the `libcalceph` library. On the MinGW system, this can be done with -lcalceph, for example

> >     gcc.exe myprogram.c -o myprogram -lcalceph

> If CALCEPH Library has been installed to a non-standard location then it may be necessary to use -I and -L compiler options to point to the right directories, and some sort of run-time path for a shared library.